@@ -161,11 +161,11 @@ void ServicesCalendarTests::testJSONParser_data()
                 "   },\n"
                 "   \"start\": {\n"
                 "       \"dateTime\": \"2010-09-22T00:00:00+04:00\",\n"
-                "       \"timeZone\": \"UTC\"\n"
+                "       \"timeZone\": \"Europe/Moscow\"\n"
                 "   },\n"
                 "   \"end\": {\n"
                 "       \"dateTime\": \"2010-09-22T00:05:00+04:00\",\n"
-                "       \"timeZone\": \"UTC\"\n"
+                "       \"timeZone\": \"Europe/Moscow\"\n"
                 "   },\n"
                 "   \"recurrence\": [\n"
                 "       \"RRULE:FREQ=MONTHLY;UNTIL=20150521\"\n"
